@@ -7,6 +7,7 @@ use uuid::Uuid;
 use crate::context::Context;
 use crate::customer::{Address, Contact};
 use crate::error::{new_application_error, new_invalid_state_error, Error};
+use crate::internal_context::InternalContext;
 use crate::inventory::ReserveResult;
 use crate::invoice::Invoice;
 use crate::item::Item;
@@ -119,7 +120,7 @@ impl Checkout {
     async fn enter_payment_in_progress_state<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        args: Option<<C as PaymentProcessor>::ProcessArgs>,
+        args: <C as PaymentProcessor>::ProcessArgs,
         deadline: DateTime<Utc>,
     ) -> Result<(), Error> {
         let charge_amount = self.invoice.as_ref().unwrap().initial_charge_amount.clone();
@@ -165,7 +166,7 @@ impl Checkout {
     async fn ensure_payment_in_progress_state<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        args: Option<<C as PaymentProcessor>::ProcessArgs>,
+        args: <C as PaymentProcessor>::ProcessArgs,
     ) -> Result<(), Error> {
         match self.state {
             State::PaymentInProgress(_) => Ok(()),
@@ -395,7 +396,7 @@ impl Checkout {
     pub async fn initiate_payment<C: Context + Send>(
         &mut self,
         ctx: &mut C,
-        args: Option<<C as PaymentProcessor>::ProcessArgs>,
+        args: <C as PaymentProcessor>::ProcessArgs,
     ) -> Result<(), Error> {
         self.ensure_payment_in_progress_state(ctx, args).await?;
 
@@ -404,8 +405,9 @@ impl Checkout {
 
     pub async fn initiate_order<C: Context + Send>(
         &mut self,
+        internal_ctx: &InternalContext,
         ctx: &mut C,
-        payment_args: Option<<C as PaymentProcessor>::ProcessArgs>,
+        payment_args: <C as PaymentProcessor>::ProcessArgs,
     ) -> Result<(), Error> {
         if !matches!(self.state, State::ItemsConfirmed(_)) {
             return Err(new_invalid_state_error(
@@ -414,7 +416,8 @@ impl Checkout {
         }
 
         self.ensure_completed_state().await?;
-        let order = Order::new_from_checkout_missing_payment(ctx, self, payment_args).await?;
+        let order =
+            Order::new_from_checkout_missing_payment(internal_ctx, ctx, self, payment_args).await?;
         self.order_id = Some(order.id.clone());
 
         ctx.update_checkout(self).await
@@ -440,7 +443,11 @@ impl Checkout {
         }
     }
 
-    pub async fn complete<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
+    pub async fn complete<C: Context + Send>(
+        &mut self,
+        internal_ctx: &InternalContext,
+        ctx: &mut C,
+    ) -> Result<(), Error> {
         if !matches!(self.state, State::PaymentInProgress(_)) {
             return Err(new_invalid_state_error(
                 "must be in the PaymentInProgress state",
@@ -448,7 +455,7 @@ impl Checkout {
         }
 
         self.ensure_completed_state().await?;
-        let order = Order::new_from_checkout(ctx, self).await?;
+        let order = Order::new_from_checkout(internal_ctx, ctx, self).await?;
         self.order_id = Some(order.id.clone());
 
         ctx.update_checkout(self).await
