@@ -9,13 +9,13 @@ use crate::error::Error;
 use crate::money::Money;
 use crate::shipping::FulfillmentType;
 
-#[derive(Serialize, Deserialize, JsonSchema)]
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub enum Tax {
     Percentage(String, Decimal),
     Absolute(String, Money),
 }
 
-#[derive(Serialize, Deserialize, JsonSchema)]
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct LineItem {
     pub title: String,
     pub quantity: u64,
@@ -23,7 +23,7 @@ pub struct LineItem {
     pub discount: Money,
 }
 
-#[derive(Serialize, Deserialize, JsonSchema)]
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct Invoice {
     pub line_items: Vec<LineItem>,
     pub shipping: Option<LineItem>,
