@@ -15,9 +15,11 @@ pub mod inventory;
 pub mod invoice;
 pub mod item;
 pub mod money;
+pub mod order;
 pub mod payment;
 pub mod price;
 pub mod product;
+pub mod pubsub_server;
 pub mod server;
 pub mod shipping;
 pub mod transaction;
