@@ -1,6 +1,8 @@
 use async_trait::async_trait;
+use cloud_pubsub;
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
+use serde_json;
 use uuid::Uuid;
 
 use crate::{
@@ -46,6 +48,18 @@ pub enum LookupKey {
     OrderId(String),
 }
 
+impl cloud_pubsub::FromPubSubMessage for LookupKey {
+    fn from(message: cloud_pubsub::EncodedMessage) -> Result<Self, cloud_pubsub::error::Error> {
+        match message.decode() {
+            Ok(bytes) => {
+                let val: LookupKey = serde_json::from_slice(&bytes).unwrap();
+                Ok(val)
+            }
+            Err(e) => Err(cloud_pubsub::error::Error::from(e)),
+        }
+    }
+}
+
 #[async_trait]
 pub trait OrderStore {
     async fn create_order(&mut self, order: &Order) -> Result<(), Error>;
